@@ -24,12 +24,13 @@ from cioc4d.sections.software_section import SoftwareSection
 from cioc4d.sections.task_section import TaskSection
 from cioc4d.sections.upload_options_section import UploadOptionsSection
 # End of Sections
-from ciocore import data as coredata
-from ciocore.expander import Expander
 
 from cioc4d import submit
-from ciocore.validator import ValidationError
 from cioc4d import validation
+from cioc4d import const as k
+from ciocore import data as coredata
+from ciocore.expander import Expander
+from ciocore.validator import ValidationError
 from ciocore.gpath import Path
 
 class ConductorDialog(c4d.gui.GeDialog):
@@ -253,10 +254,11 @@ class ConductorDialog(c4d.gui.GeDialog):
 
     def on_connect(self):
 
+        use_fixtures = self.section("DiagnosticsSection").fixture_widget.get_value()
+        fixtures_dir = k.FIXTURES_DIR if use_fixtures else None
+        coredata.set_fixtures_dir(fixtures_dir)
         try:
-            try_cache = self.section(
-                "DiagnosticsSection").fixture_widget.get_value()
-            coredata.data(force=True, try_cache=try_cache)
+            coredata.data(force=True)
             self.foot_grp.enable_submit(True)
             return
         except BaseException:
@@ -265,7 +267,6 @@ class ConductorDialog(c4d.gui.GeDialog):
             raise
         self.foot_grp.enable_submit(False)
 
-
     def on_reset(self):
         self.store.reset()
         self.store.commit()
