@@ -106,6 +106,8 @@ class FramesSection(CollapsibleSection):
             return
 
     def resolve(self, expander, **kwargs ):
+        if  self.dialog.section("UploadOptionsSection").upload_only_widget.get_value():
+            return {}
         tasks = []
         max_tasks = kwargs.get("max_tasks", -1)
         if self.dialog.section("TaskSection").widget.get_visible():
@@ -148,6 +150,7 @@ class FramesSection(CollapsibleSection):
             self.custom_range_widget.checkbox_id,
             self.custom_range_widget.text_field_id,
             self.scout_frames_widget.checkbox_id,
-            self.scout_frames_widget.text_field_id
+            self.scout_frames_widget.text_field_id,
+            self.dialog.section("UploadOptionsSection").upload_only_widget.checkbox_id
         ]
  
\ No newline at end of file
