@@ -108,7 +108,7 @@ class GeneralSection(CollapsibleSection):
     def resolve(self, expander, **kwargs):
         instance_type = self.get_selected_instance_type()
 
-        dest_path = Path(self._get_destination_path()).posix_path()
+        dest_path = Path(self.resolve_destination_path()).posix_path()
 
         return {
             "job_title": expander.evaluate(self.title_widget.get_value()),
@@ -118,7 +118,33 @@ class GeneralSection(CollapsibleSection):
             "preemptible": self.instance_types_widget.get_checkbox_value()
         }
 
+
+    
+    def set_store_affectors(self):
+        """
+        collect widget IDs that trigger store update.
+
+        These are usually the same affectors that trigger a preview. However
+        this is a special case because we also need to update the store with the
+        destination dir state when the user flips the task visibility switch,
+        and since the task visibility switch is not in the preview_affectors
+        list for this section, we ust append it.
+
+        You may be wondering, why the task toggle id is not in preview_affectors
+        here. It's because the whole preview is updated anyway when the task
+        toggle changes so its handled in the TaskSection. Store updates on the
+        other hand, only write the one sections properties to the store.
+        """
+        task_widget_toggle_id = self.dialog.section("TaskSection").widget.checkbox_id
+
+        self._store_affectors = self.get_preview_affectors() + [task_widget_toggle_id]
+
+  
+  
     def get_preview_affectors(self):
+        """
+        
+        """
         return [
             self.takes_widget.combo_box_id,
             self.title_widget.text_field_id,
@@ -129,7 +155,7 @@ class GeneralSection(CollapsibleSection):
             self.instance_types_widget.checkbox_id
         ]
 
-    def _get_destination_path(self):
+    def resolve_destination_path(self):
         """
         Resolve the destination path in one of 2 ways.
 
