@@ -10,7 +10,7 @@ from cioc4d import asset_cache
 from ciocore.gpath import Path
 from ciocore.gpath_list import GLOBBABLE_REGEX, PathList
 from ciocore.validator import ValidationError, Validator
-from cioc4d.conductor_dialog import DEFAULT_TASK_TEMPLATE
+from cioc4d.conductor_store import DEFAULT_TASK_TEMPLATE
 
 class ValidateUploadDaemon(Validator):
     def run(self, _):
@@ -136,7 +136,7 @@ You should change either the path in Render Settings, or the Conductor destinati
             self.add_notice(
                 """Your task template overrides the Render Settings image path with the {} flag. 
 This is fine, but please ensure it points to a writable directory. 
-It should be somewhere inside the Destination Directory. Check the Preview pane.""".format(override_flag))
+It should be somewhere inside the Destination Directory. Check the Preview panel.""".format(override_flag))
             return
 
         image_path = render_data[c4d_filename_id]
